@@ -1,12 +1,20 @@
 import nltk
 
 from nltk.tokenize import RegexpTokenizer
-
+from syllable import Encoder
 
 TOKENIZER = RegexpTokenizer('(?u)\W+|\$[\d\.]+|\S+')
 SPECIAL_CHARS = ['.', ',', '!', '?']
 
 
+def get_syllable_count(words):
+    encoder = Encoder(lang="tr", limitby="vocabulary", limit=3000)
+    syllable_cnt = 0
+    for word in words:
+        syllable_cnt = syllable_cnt + len(encoder.tokenize(word).split())
+    
+    return syllable_cnt
+
 def get_char_count(words):
     characters = 0
     for word in words:
